#!/usr/bin/env bash
set -Eeuo pipefail

[ -f versions.json ] # run "versions.sh" first

cd "$(dirname "$(readlink -f "$BASH_SOURCE")")"

jqt='.jq-template.awk'
if [ -n "${BASHBREW_SCRIPTS:-}" ]; then
	jqt="$BASHBREW_SCRIPTS/jq-template.awk"
elif [ "$BASH_SOURCE" -nt "$jqt" ]; then
	wget -qO "$jqt" 'https://github.com/docker-library/bashbrew/raw/5f0c26381fb7cc78b2d217d58007800bdcfbcfa1/scripts/jq-template.awk'
fi

if [ "$#" -eq 0 ]; then
	versions="$(jq -r 'keys | map(@sh) | join(" ")' versions.json)"
	eval "set -- $versions"
fi

generated_warning() {
	cat <<-EOH
		#
		# NOTE: THIS DOCKERFILE IS GENERATED VIA "apply-templates.sh"
		#
		# PLEASE DO NOT EDIT IT DIRECTLY.
		#

	EOH
}

for version; do
	export version

	for variant in oracle debian; do
		export variant

		variantVersion="$(jq -r '.[env.version][env.variant] // {} | .version // ""' versions.json)"
		if [ -n "$variantVersion" ]; then
			dockerfile="Dockerfile.$variant"
			{
				generated_warning
				gawk -f "$jqt" "template/$dockerfile"
			} > "$version/$dockerfile"
		fi
	done

	cp -a template/docker-entrypoint.sh "$version/docker-entrypoint.sh"
done
